package dao

import (
	"github.com/jinzhu/gorm"
	"time"
)

// AlarmTerminal 一键报警服务
type AlarmTerminal struct {
	ID               int       `gorm:"primary_key" json:"id"`                     //编号
	TerminalName     string    `gorm:" varchar(64)" json:"terminalName"`          //设备名称
	TerminalSN       string    `gorm:"type:varchar(60)" json:"terminalSN"`        //设备序编码
	BrandID          int       `gorm:"type:int" json:"brandID"`                   //设备品牌ID
	ModelID          int       `gorm:"type:int" json:"modelID"`                   //设备型号ID
	GatewayID        int       `gorm:"type: int" json:"gatewayID"`                //所属网关
	LampPoleID       int       `gorm:"type: int" json:"lampPoleID"`               //所属灯杆 灯杆ID
	LampPoleName     string    `gorm:"type: varchar(64)" json:"lampPoleName"`     //灯杆名称
	LampPoleSN       string    `gorm:"type: varchar(64)" json:"lampPoleSN"`       //灯杆编码
	LampPoleLocation string    `gorm:"type:varchar(255)" json:"lampPoleLocation"` //灯杆安装位置
	PoleLng          float64   `gorm:"type:double(17, 14) " json:"poleLng"`       //经度
	PoleLat          float64   `gorm:"type:double(17, 14)  " json:"poleLat"`      //纬度
	Numeration       int       `gorm:"type: int" json:"numeration"`               //编号
	ServeID          int       `gorm:"type:int" json:"serveID"`                   //所属服务ID
	IPAddress        string    `gorm:"type:varchar(50)" json:"ipAddress"`         //IP地址
	InstallTime      time.Time `gorm:"type:date" json:"installTime"`              //安装时间
	TenantId         string    `gorm:"type:varchar(12)" json:"tenantId"`          //租户id
	CreateTime       time.Time `gorm:"type:datetime" json:"createTime"`           //新增时间
	CreateUser       string    `gorm:"type:varchar(60)" json:"createUser"`        //新增记录操作用户ID
	UpdateTime       time.Time `gorm:"type:datetime" json:"updateTime"`           //修改时间
	UpdateUser       string    `gorm:"type:varchar(60)" json:"updateUser"`        //修改用户
	IsDeleted        int       `gorm:"type:int" json:"isDeleted"`                 //是否删除 0=未删除,1=删除
	Status           int       `gorm:"type:int  " json:"status"`                  //告警状态 1处理完成2待处理3无需处理
	Tag              string    `gorm:"type:varchar(255)" json:"tag"`              //标签，(备用，逗号区分)
}

func (AlarmTerminal) TableName() string {
	return "t_dev_a_key_alarm_terminal"
}

func (c AlarmTerminal) Delete() error {
	return Db.Model(&c).Where("id = ?", c.ID).Updates(map[string]interface{}{"update_time": c.UpdateTime,
		"update_user": c.UpdateUser, "is_deleted": c.IsDeleted}).Error
}

func (c AlarmTerminal) IsExistedBySN() bool {
	var count = 0
	_ = Db.Model(&c).Where("  terminal_sn = ? and is_deleted = ?",
		c.TerminalSN, c.IsDeleted).Count(&count).Error
	return count > 0
}

func (c AlarmTerminal) IsExistedByNameAndCode() bool {
	var devices []AlarmTerminal
	err := Db.Model(&c).Where(" terminal_sn = ? and is_deleted = ?",
		c.TerminalSN, c.IsDeleted).Find(&devices).Error
	//如果查询不到，返回相应的错误
	if gorm.IsRecordNotFoundError(err) {
		return false
	}
	for _, d := range devices {
		if d.ID != c.ID {
			return true
		}
	}
	return false
}

func (c *AlarmTerminal) Create() error {
	return Db.Model(&c).Save(&c).Error
}

func (c *AlarmTerminal) Update() error {
	return Db.Model(&c).Where(" id = ? ", c.ID).Update(&c).Error
}

func (c *AlarmTerminal) GetDevice() error {
	err := Db.Model(&c).Where(" id = ? ", c.ID).Scan(&c).Error
	return err
}

func (c AlarmTerminal) GetDevices(offset, limit int) ([]AlarmTerminal, error) {
	var devices []AlarmTerminal
	err := Db.Model(&c).Where(" terminal_name like ? and is_deleted = 0", "%"+c.TerminalName+"%").Offset(offset).Limit(limit).Find(&devices).Error
	return devices, err
}

func (c AlarmTerminal) GetAllDevices() ([]*AlarmTerminal, error) {
	var devices []*AlarmTerminal
	err := Db.Model(&c).Where(" tenant_id = ? and is_deleted = ? ", c.TenantId, c.IsDeleted).Scan(&devices).Error
	return devices, err
}
